# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class ContextApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def batch_archive_context_labels(
        self,
        **kwargs: Any,
    ) -> None: ...

    def batch_archive_context_labels_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def batch_create_context_labels(
        self,
        **kwargs: Any,
    ) -> List[ContextLabelOutputV1]: ...

    def batch_create_context_labels_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_comment_category(
        self,
        **kwargs: Any,
    ) -> CommentCategoryOutputV1: ...

    def create_comment_category_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_context_comment(
        self,
        **kwargs: Any,
    ) -> ContextCommentOutputV1: ...

    def create_context_comment_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_context_label(
        self,
        **kwargs: Any,
    ) -> ContextLabelOutputV1: ...

    def create_context_label_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_context_numeric(
        self,
        **kwargs: Any,
    ) -> ContextNumericOutputV1: ...

    def create_context_numeric_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_context_opaque(
        self,
        **kwargs: Any,
    ) -> ContextOpaqueOutputV1: ...

    def create_context_opaque_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_label(
        self,
        **kwargs: Any,
    ) -> LabelOutputV1: ...

    def create_label_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_label_category(
        self,
        **kwargs: Any,
    ) -> LabelCategoryOutputV1: ...

    def create_label_category_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_numeric_description(
        self,
        **kwargs: Any,
    ) -> NumericDescriptionOutputV1: ...

    def create_numeric_description_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_comment_category(
        self,
        **kwargs: Any,
    ) -> None: ...

    def delete_comment_category_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_context_comment(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_context_comment_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_context_label(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def delete_context_label_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_context_numeric(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_context_numeric_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_context_opaque(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_context_opaque_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_label(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def delete_label_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_label_category(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def delete_label_category_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_numeric_description(
        self,
        **kwargs: Any,
    ) -> None: ...

    def delete_numeric_description_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def find_label_categories(
        self,
        **kwargs: Any,
    ) -> LabelCategoryOutputListV1: ...

    def find_label_categories_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def find_labels(
        self,
        **kwargs: Any,
    ) -> LabelOutputListV1: ...

    def find_labels_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_all_comment_categories(
        self,
        **kwargs: Any,
    ) -> CommentCategoryOutputListV1: ...

    def get_all_comment_categories_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_all_context(
        self,
        **kwargs: Any,
    ) -> AllContextOutputV1: ...

    def get_all_context_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_all_numeric_descriptions(
        self,
        **kwargs: Any,
    ) -> NumericDescriptionOutputListV1: ...

    def get_all_numeric_descriptions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_comment_category(
        self,
        **kwargs: Any,
    ) -> CommentCategoryOutputV1: ...

    def get_comment_category_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_context_comments(
        self,
        **kwargs: Any,
    ) -> ContextCommentListOutputV1: ...

    def get_context_comments_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_context_conditions(
        self,
        **kwargs: Any,
    ) -> ContextConditionOutputListV1: ...

    def get_context_conditions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_context_labels(
        self,
        **kwargs: Any,
    ) -> ContextLabelListOutputV1: ...

    def get_context_labels_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_context_numerics(
        self,
        **kwargs: Any,
    ) -> ContextNumericListOutputV1: ...

    def get_context_numerics_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_context_opaque(
        self,
        **kwargs: Any,
    ) -> ContextOpaqueListOutputV1: ...

    def get_context_opaque_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_label_hierarchies(
        self,
        **kwargs: Any,
    ) -> LabelHierarchyOutputListV1: ...

    def get_label_hierarchies_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_labeled_items(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_labeled_items_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_numeric_description(
        self,
        **kwargs: Any,
    ) -> NumericDescriptionOutputV1: ...

    def get_numeric_description_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_numeric_description_with_path_id(
        self,
        **kwargs: Any,
    ) -> NumericDescriptionOutputV1: ...

    def get_numeric_description_with_path_id_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_comment_category(
        self,
        **kwargs: Any,
    ) -> CommentCategoryOutputV1: ...

    def update_comment_category_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_context_comment(
        self,
        **kwargs: Any,
    ) -> ContextCommentOutputV1: ...

    def update_context_comment_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_context_numeric(
        self,
        **kwargs: Any,
    ) -> ContextNumericOutputV1: ...

    def update_context_numeric_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_context_opaque(
        self,
        **kwargs: Any,
    ) -> ContextOpaqueOutputV1: ...

    def update_context_opaque_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_label(
        self,
        **kwargs: Any,
    ) -> LabelOutputV1: ...

    def update_label_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_label_category(
        self,
        **kwargs: Any,
    ) -> LabelCategoryOutputV1: ...

    def update_label_category_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_numeric_description(
        self,
        **kwargs: Any,
    ) -> ContextNumericOutputV1: ...

    def update_numeric_description_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TreeItemOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _cached: Optional[bool]
    _children: Optional[List[TreeItemOutputV1]]
    _created_by: Optional[str]
    _datasource: Optional[DatasourcePreviewV1]
    _description: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _evidence_table_definition_id: Optional[str]
    _fingerprint: Optional[str]
    _has_active_children: Optional[bool]
    _has_children: Optional[bool]
    _id: str
    _is_archived: Optional[bool]
    _is_redacted: Optional[bool]
    _manually_added: Optional[str]
    _name: str
    _parameters: Optional[List[FormulaParameterOutputV1]]
    _properties: List[PropertyOutputV1]
    _scoped_to: Optional[str]
    _status_message: Optional[str]
    _translation_key: Optional[str]
    _type: str
    _value_unit_of_measure: Optional[str]
    _workbook_id: Optional[str]


    def __init__(
        self,
        cached: Optional[bool] = False,
        children: Optional[List[TreeItemOutputV1]] = None,
        created_by: Optional[str] = None,
        datasource: Optional[DatasourcePreviewV1] = None,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        evidence_table_definition_id: Optional[str] = None,
        fingerprint: Optional[str] = None,
        has_active_children: Optional[bool] = False,
        has_children: Optional[bool] = False,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        manually_added: Optional[str] = None,
        name: Optional[str] = None,
        parameters: Optional[List[FormulaParameterOutputV1]] = None,
        properties: Optional[List[PropertyOutputV1]] = None,
        scoped_to: Optional[str] = None,
        status_message: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        value_unit_of_measure: Optional[str] = None,
        workbook_id: Optional[str] = None,
    ) -> None: ...

    @property
    def cached(self) -> Optional[bool]: ...

    @cached.setter
    def cached(self, cached: Optional[bool]) -> None: ...

    @property
    def children(self) -> Optional[List[TreeItemOutputV1]]: ...

    @children.setter
    def children(self, children: Optional[List[TreeItemOutputV1]]) -> None: ...

    @property
    def created_by(self) -> Optional[str]: ...

    @created_by.setter
    def created_by(self, created_by: Optional[str]) -> None: ...

    @property
    def datasource(self) -> Optional[DatasourcePreviewV1]: ...

    @datasource.setter
    def datasource(self, datasource: Optional[DatasourcePreviewV1]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def evidence_table_definition_id(self) -> Optional[str]: ...

    @evidence_table_definition_id.setter
    def evidence_table_definition_id(self, evidence_table_definition_id: Optional[str]) -> None: ...

    @property
    def fingerprint(self) -> Optional[str]: ...

    @fingerprint.setter
    def fingerprint(self, fingerprint: Optional[str]) -> None: ...

    @property
    def has_active_children(self) -> Optional[bool]: ...

    @has_active_children.setter
    def has_active_children(self, has_active_children: Optional[bool]) -> None: ...

    @property
    def has_children(self) -> Optional[bool]: ...

    @has_children.setter
    def has_children(self, has_children: Optional[bool]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def manually_added(self) -> Optional[str]: ...

    @manually_added.setter
    def manually_added(self, manually_added: Optional[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def parameters(self) -> Optional[List[FormulaParameterOutputV1]]: ...

    @parameters.setter
    def parameters(self, parameters: Optional[List[FormulaParameterOutputV1]]) -> None: ...

    @property
    def properties(self) -> List[PropertyOutputV1]: ...

    @properties.setter
    def properties(self, properties: List[PropertyOutputV1]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def value_unit_of_measure(self) -> Optional[str]: ...

    @value_unit_of_measure.setter
    def value_unit_of_measure(self, value_unit_of_measure: Optional[str]) -> None: ...

    @property
    def workbook_id(self) -> Optional[str]: ...

    @workbook_id.setter
    def workbook_id(self, workbook_id: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ManualRunInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'condition_id': 'str',
        'look_ahead_duration_seconds': 'int',
        'lookback_duration_seconds': 'int',
        'table_batch_action': 'str'
    }

    attribute_map = {
        'condition_id': 'conditionId',
        'look_ahead_duration_seconds': 'lookAheadDurationSeconds',
        'lookback_duration_seconds': 'lookbackDurationSeconds',
        'table_batch_action': 'tableBatchAction'
    }

    def __init__(self, condition_id=None, look_ahead_duration_seconds=None, lookback_duration_seconds=None, table_batch_action=None):
        """
        ManualRunInputV1 - a model defined in Swagger
        """

        self._condition_id = None
        self._look_ahead_duration_seconds = None
        self._lookback_duration_seconds = None
        self._table_batch_action = None

        if condition_id is not None:
          self.condition_id = condition_id
        if look_ahead_duration_seconds is not None:
          self.look_ahead_duration_seconds = look_ahead_duration_seconds
        if lookback_duration_seconds is not None:
          self.lookback_duration_seconds = lookback_duration_seconds
        if table_batch_action is not None:
          self.table_batch_action = table_batch_action

    @property
    def condition_id(self):
        """
        Gets the condition_id of this ManualRunInputV1.
        The ID of condition to run the condition monitor job on

        :return: The condition_id of this ManualRunInputV1.
        :rtype: str
        """
        return self._condition_id

    @condition_id.setter
    def condition_id(self, condition_id):
        """
        Sets the condition_id of this ManualRunInputV1.
        The ID of condition to run the condition monitor job on

        :param condition_id: The condition_id of this ManualRunInputV1.
        :type: str
        """
        if condition_id is None:
            raise ValueError("Invalid value for `condition_id`, must not be `None`")

        self._condition_id = condition_id

    @property
    def look_ahead_duration_seconds(self):
        """
        Gets the look_ahead_duration_seconds of this ManualRunInputV1.
        How far to look forward for capsules, in seconds

        :return: The look_ahead_duration_seconds of this ManualRunInputV1.
        :rtype: int
        """
        return self._look_ahead_duration_seconds

    @look_ahead_duration_seconds.setter
    def look_ahead_duration_seconds(self, look_ahead_duration_seconds):
        """
        Sets the look_ahead_duration_seconds of this ManualRunInputV1.
        How far to look forward for capsules, in seconds

        :param look_ahead_duration_seconds: The look_ahead_duration_seconds of this ManualRunInputV1.
        :type: int
        """

        self._look_ahead_duration_seconds = look_ahead_duration_seconds

    @property
    def lookback_duration_seconds(self):
        """
        Gets the lookback_duration_seconds of this ManualRunInputV1.
        How far to look back for capsules, in seconds

        :return: The lookback_duration_seconds of this ManualRunInputV1.
        :rtype: int
        """
        return self._lookback_duration_seconds

    @lookback_duration_seconds.setter
    def lookback_duration_seconds(self, lookback_duration_seconds):
        """
        Sets the lookback_duration_seconds of this ManualRunInputV1.
        How far to look back for capsules, in seconds

        :param lookback_duration_seconds: The lookback_duration_seconds of this ManualRunInputV1.
        :type: int
        """
        if lookback_duration_seconds is None:
            raise ValueError("Invalid value for `lookback_duration_seconds`, must not be `None`")

        self._lookback_duration_seconds = lookback_duration_seconds

    @property
    def table_batch_action(self):
        """
        Gets the table_batch_action of this ManualRunInputV1.
        What table action to take before publishing manual run capsules. This can apply to specific conditions or all conditions depending on context

        :return: The table_batch_action of this ManualRunInputV1.
        :rtype: str
        """
        return self._table_batch_action

    @table_batch_action.setter
    def table_batch_action(self, table_batch_action):
        """
        Sets the table_batch_action of this ManualRunInputV1.
        What table action to take before publishing manual run capsules. This can apply to specific conditions or all conditions depending on context

        :param table_batch_action: The table_batch_action of this ManualRunInputV1.
        :type: str
        """

        self._table_batch_action = table_batch_action

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ManualRunInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class CustomAgentsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def archive_custom_agent(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_custom_agent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_custom_agent(
        self,
        **kwargs: Any,
    ) -> CustomAgentOutputV1: ...

    def create_custom_agent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_custom_agent_draft(
        self,
        **kwargs: Any,
    ) -> CustomAgentOutputV1: ...

    def create_custom_agent_draft_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_custom_agent_version(
        self,
        **kwargs: Any,
    ) -> List[CustomAgentVersionOutputV1]: ...

    def create_custom_agent_version_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def discard_custom_agent_draft(
        self,
        **kwargs: Any,
    ) -> None: ...

    def discard_custom_agent_draft_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def duplicate_custom_agent(
        self,
        **kwargs: Any,
    ) -> CustomAgentOutputV1: ...

    def duplicate_custom_agent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_custom_agent(
        self,
        **kwargs: Any,
    ) -> CustomAgentOutputV1: ...

    def get_custom_agent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_custom_agent_draft_working_copies(
        self,
        **kwargs: Any,
    ) -> List[CustomAgentDraftOutputV1]: ...

    def get_custom_agent_draft_working_copies_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_custom_agent_version_graph(
        self,
        **kwargs: Any,
    ) -> CustomAgentOutputV1: ...

    def get_custom_agent_version_graph_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_custom_agent_versions(
        self,
        **kwargs: Any,
    ) -> List[CustomAgentVersionOutputV1]: ...

    def get_custom_agent_versions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_custom_agents(
        self,
        **kwargs: Any,
    ) -> List[CustomAgentSummaryOutputV1]: ...

    def get_custom_agents_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def revert_custom_agent_to_version(
        self,
        **kwargs: Any,
    ) -> CustomAgentOutputV1: ...

    def revert_custom_agent_to_version_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_custom_agent_production(
        self,
        **kwargs: Any,
    ) -> List[CustomAgentVersionOutputV1]: ...

    def set_custom_agent_production_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_custom_agent(
        self,
        **kwargs: Any,
    ) -> CustomAgentOutputV1: ...

    def update_custom_agent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_custom_agent_draft(
        self,
        **kwargs: Any,
    ) -> CustomAgentOutputV1: ...

    def update_custom_agent_draft_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ItemFinderInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _cron_schedule: Optional[List[str]]
    _description: Optional[str]
    _enabled: Optional[bool]
    _fixed_list_searches: Optional[List[FixedListSearchV1]]
    _hierarchy_searches: Optional[List[HierarchySearchV1]]
    _include_hierarchy: Optional[bool]
    _name: str
    _property_searches: Optional[List[PropertySearchV1]]
    _scaling_table_uuid_column_searches: Optional[List[ScalingTableUUIDColumnSearchV1]]
    _scoped_to: Optional[str]
    _searches: Optional[List[SwapAcrossAssetsSearchV1]]
    _skip_job_scheduling: Optional[bool]
    _stored_table_searches: Optional[List[StoredTableSearchV1]]
    _timezone: Optional[str]


    def __init__(
        self,
        cron_schedule: Optional[List[str]] = None,
        description: Optional[str] = None,
        enabled: Optional[bool] = True,
        fixed_list_searches: Optional[List[FixedListSearchV1]] = None,
        hierarchy_searches: Optional[List[HierarchySearchV1]] = None,
        include_hierarchy: Optional[bool] = False,
        name: Optional[str] = None,
        property_searches: Optional[List[PropertySearchV1]] = None,
        scaling_table_uuid_column_searches: Optional[List[ScalingTableUUIDColumnSearchV1]] = None,
        scoped_to: Optional[str] = None,
        searches: Optional[List[SwapAcrossAssetsSearchV1]] = None,
        skip_job_scheduling: Optional[bool] = False,
        stored_table_searches: Optional[List[StoredTableSearchV1]] = None,
        timezone: Optional[str] = None,
    ) -> None: ...

    @property
    def cron_schedule(self) -> Optional[List[str]]: ...

    @cron_schedule.setter
    def cron_schedule(self, cron_schedule: Optional[List[str]]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def enabled(self) -> Optional[bool]: ...

    @enabled.setter
    def enabled(self, enabled: Optional[bool]) -> None: ...

    @property
    def fixed_list_searches(self) -> Optional[List[FixedListSearchV1]]: ...

    @fixed_list_searches.setter
    def fixed_list_searches(self, fixed_list_searches: Optional[List[FixedListSearchV1]]) -> None: ...

    @property
    def hierarchy_searches(self) -> Optional[List[HierarchySearchV1]]: ...

    @hierarchy_searches.setter
    def hierarchy_searches(self, hierarchy_searches: Optional[List[HierarchySearchV1]]) -> None: ...

    @property
    def include_hierarchy(self) -> Optional[bool]: ...

    @include_hierarchy.setter
    def include_hierarchy(self, include_hierarchy: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def property_searches(self) -> Optional[List[PropertySearchV1]]: ...

    @property_searches.setter
    def property_searches(self, property_searches: Optional[List[PropertySearchV1]]) -> None: ...

    @property
    def scaling_table_uuid_column_searches(self) -> Optional[List[ScalingTableUUIDColumnSearchV1]]: ...

    @scaling_table_uuid_column_searches.setter
    def scaling_table_uuid_column_searches(self, scaling_table_uuid_column_searches: Optional[List[ScalingTableUUIDColumnSearchV1]]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def searches(self) -> Optional[List[SwapAcrossAssetsSearchV1]]: ...

    @searches.setter
    def searches(self, searches: Optional[List[SwapAcrossAssetsSearchV1]]) -> None: ...

    @property
    def skip_job_scheduling(self) -> Optional[bool]: ...

    @skip_job_scheduling.setter
    def skip_job_scheduling(self, skip_job_scheduling: Optional[bool]) -> None: ...

    @property
    def stored_table_searches(self) -> Optional[List[StoredTableSearchV1]]: ...

    @stored_table_searches.setter
    def stored_table_searches(self, stored_table_searches: Optional[List[StoredTableSearchV1]]) -> None: ...

    @property
    def timezone(self) -> Optional[str]: ...

    @timezone.setter
    def timezone(self, timezone: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ConnectionOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _additional_config_json: Optional[str]
    _agent_name: Optional[str]
    _backups: Optional[List[JsonBackupOutputV1]]
    _configured_fields_json: Optional[str]
    _connection_id: Optional[str]
    _connector_name: Optional[str]
    _created_at: Optional[str]
    _datasource_class: Optional[str]
    _datasource_id: Optional[str]
    _description: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _enabled: Optional[bool]
    _field_configurations: Optional[List[ConfigFieldV1]]
    _id: str
    _indexing_connection: Optional[bool]
    _is_archived: Optional[bool]
    _is_redacted: Optional[bool]
    _json: Optional[str]
    _max_concurrent_requests: Optional[int]
    _max_results_per_requests: Optional[int]
    _name: str
    _propagation_pending: Optional[bool]
    _pull_connection: Optional[bool]
    _status_message: Optional[str]
    _transforms: Optional[str]
    _translation_key: Optional[str]
    _type: str
    _updated_at: Optional[str]


    def __init__(
        self,
        additional_config_json: Optional[str] = None,
        agent_name: Optional[str] = None,
        backups: Optional[List[JsonBackupOutputV1]] = None,
        configured_fields_json: Optional[str] = None,
        connection_id: Optional[str] = None,
        connector_name: Optional[str] = None,
        created_at: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        enabled: Optional[bool] = False,
        field_configurations: Optional[List[ConfigFieldV1]] = None,
        id: Optional[str] = None,
        indexing_connection: Optional[bool] = False,
        is_archived: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        json: Optional[str] = None,
        max_concurrent_requests: Optional[int] = None,
        max_results_per_requests: Optional[int] = None,
        name: Optional[str] = None,
        propagation_pending: Optional[bool] = False,
        pull_connection: Optional[bool] = False,
        status_message: Optional[str] = None,
        transforms: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def additional_config_json(self) -> Optional[str]: ...

    @additional_config_json.setter
    def additional_config_json(self, additional_config_json: Optional[str]) -> None: ...

    @property
    def agent_name(self) -> Optional[str]: ...

    @agent_name.setter
    def agent_name(self, agent_name: Optional[str]) -> None: ...

    @property
    def backups(self) -> Optional[List[JsonBackupOutputV1]]: ...

    @backups.setter
    def backups(self, backups: Optional[List[JsonBackupOutputV1]]) -> None: ...

    @property
    def configured_fields_json(self) -> Optional[str]: ...

    @configured_fields_json.setter
    def configured_fields_json(self, configured_fields_json: Optional[str]) -> None: ...

    @property
    def connection_id(self) -> Optional[str]: ...

    @connection_id.setter
    def connection_id(self, connection_id: Optional[str]) -> None: ...

    @property
    def connector_name(self) -> Optional[str]: ...

    @connector_name.setter
    def connector_name(self, connector_name: Optional[str]) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def datasource_class(self) -> Optional[str]: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: Optional[str]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def enabled(self) -> Optional[bool]: ...

    @enabled.setter
    def enabled(self, enabled: Optional[bool]) -> None: ...

    @property
    def field_configurations(self) -> Optional[List[ConfigFieldV1]]: ...

    @field_configurations.setter
    def field_configurations(self, field_configurations: Optional[List[ConfigFieldV1]]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def indexing_connection(self) -> Optional[bool]: ...

    @indexing_connection.setter
    def indexing_connection(self, indexing_connection: Optional[bool]) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def json(self) -> Optional[str]: ...

    @json.setter
    def json(self, json: Optional[str]) -> None: ...

    @property
    def max_concurrent_requests(self) -> Optional[int]: ...

    @max_concurrent_requests.setter
    def max_concurrent_requests(self, max_concurrent_requests: Optional[int]) -> None: ...

    @property
    def max_results_per_requests(self) -> Optional[int]: ...

    @max_results_per_requests.setter
    def max_results_per_requests(self, max_results_per_requests: Optional[int]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def propagation_pending(self) -> Optional[bool]: ...

    @propagation_pending.setter
    def propagation_pending(self, propagation_pending: Optional[bool]) -> None: ...

    @property
    def pull_connection(self) -> Optional[bool]: ...

    @pull_connection.setter
    def pull_connection(self, pull_connection: Optional[bool]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def transforms(self) -> Optional[str]: ...

    @transforms.setter
    def transforms(self, transforms: Optional[str]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class BoardTimeframeComparisonInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'absolute_threshold': 'float',
        'applied_filters': 'list[BoardFilterInputV1]',
        'baseline_end': 'str',
        'baseline_start': 'str',
        'current_end': 'str',
        'current_start': 'str',
        'limit': 'int',
        'metric': 'str',
        'percent_threshold': 'float',
        'tile_ids': 'list[str]'
    }

    attribute_map = {
        'absolute_threshold': 'absoluteThreshold',
        'applied_filters': 'appliedFilters',
        'baseline_end': 'baselineEnd',
        'baseline_start': 'baselineStart',
        'current_end': 'currentEnd',
        'current_start': 'currentStart',
        'limit': 'limit',
        'metric': 'metric',
        'percent_threshold': 'percentThreshold',
        'tile_ids': 'tileIds'
    }

    def __init__(self, absolute_threshold=None, applied_filters=None, baseline_end=None, baseline_start=None, current_end=None, current_start=None, limit=None, metric=None, percent_threshold=None, tile_ids=None):
        """
        BoardTimeframeComparisonInputV1 - a model defined in Swagger
        """

        self._absolute_threshold = None
        self._applied_filters = None
        self._baseline_end = None
        self._baseline_start = None
        self._current_end = None
        self._current_start = None
        self._limit = None
        self._metric = None
        self._percent_threshold = None
        self._tile_ids = None

        if absolute_threshold is not None:
          self.absolute_threshold = absolute_threshold
        if applied_filters is not None:
          self.applied_filters = applied_filters
        if baseline_end is not None:
          self.baseline_end = baseline_end
        if baseline_start is not None:
          self.baseline_start = baseline_start
        if current_end is not None:
          self.current_end = current_end
        if current_start is not None:
          self.current_start = current_start
        if limit is not None:
          self.limit = limit
        if metric is not None:
          self.metric = metric
        if percent_threshold is not None:
          self.percent_threshold = percent_threshold
        if tile_ids is not None:
          self.tile_ids = tile_ids

    @property
    def absolute_threshold(self):
        """
        Gets the absolute_threshold of this BoardTimeframeComparisonInputV1.
        Absolute change threshold when baseline is zero

        :return: The absolute_threshold of this BoardTimeframeComparisonInputV1.
        :rtype: float
        """
        return self._absolute_threshold

    @absolute_threshold.setter
    def absolute_threshold(self, absolute_threshold):
        """
        Sets the absolute_threshold of this BoardTimeframeComparisonInputV1.
        Absolute change threshold when baseline is zero

        :param absolute_threshold: The absolute_threshold of this BoardTimeframeComparisonInputV1.
        :type: float
        """

        self._absolute_threshold = absolute_threshold

    @property
    def applied_filters(self):
        """
        Gets the applied_filters of this BoardTimeframeComparisonInputV1.
        Filters to apply to the board data

        :return: The applied_filters of this BoardTimeframeComparisonInputV1.
        :rtype: list[BoardFilterInputV1]
        """
        return self._applied_filters

    @applied_filters.setter
    def applied_filters(self, applied_filters):
        """
        Sets the applied_filters of this BoardTimeframeComparisonInputV1.
        Filters to apply to the board data

        :param applied_filters: The applied_filters of this BoardTimeframeComparisonInputV1.
        :type: list[BoardFilterInputV1]
        """

        self._applied_filters = applied_filters

    @property
    def baseline_end(self):
        """
        Gets the baseline_end of this BoardTimeframeComparisonInputV1.
        Baseline range end (ISO-8601)

        :return: The baseline_end of this BoardTimeframeComparisonInputV1.
        :rtype: str
        """
        return self._baseline_end

    @baseline_end.setter
    def baseline_end(self, baseline_end):
        """
        Sets the baseline_end of this BoardTimeframeComparisonInputV1.
        Baseline range end (ISO-8601)

        :param baseline_end: The baseline_end of this BoardTimeframeComparisonInputV1.
        :type: str
        """
        if baseline_end is None:
            raise ValueError("Invalid value for `baseline_end`, must not be `None`")

        self._baseline_end = baseline_end

    @property
    def baseline_start(self):
        """
        Gets the baseline_start of this BoardTimeframeComparisonInputV1.
        Baseline range start (ISO-8601)

        :return: The baseline_start of this BoardTimeframeComparisonInputV1.
        :rtype: str
        """
        return self._baseline_start

    @baseline_start.setter
    def baseline_start(self, baseline_start):
        """
        Sets the baseline_start of this BoardTimeframeComparisonInputV1.
        Baseline range start (ISO-8601)

        :param baseline_start: The baseline_start of this BoardTimeframeComparisonInputV1.
        :type: str
        """
        if baseline_start is None:
            raise ValueError("Invalid value for `baseline_start`, must not be `None`")

        self._baseline_start = baseline_start

    @property
    def current_end(self):
        """
        Gets the current_end of this BoardTimeframeComparisonInputV1.
        Current range end (ISO-8601)

        :return: The current_end of this BoardTimeframeComparisonInputV1.
        :rtype: str
        """
        return self._current_end

    @current_end.setter
    def current_end(self, current_end):
        """
        Sets the current_end of this BoardTimeframeComparisonInputV1.
        Current range end (ISO-8601)

        :param current_end: The current_end of this BoardTimeframeComparisonInputV1.
        :type: str
        """
        if current_end is None:
            raise ValueError("Invalid value for `current_end`, must not be `None`")

        self._current_end = current_end

    @property
    def current_start(self):
        """
        Gets the current_start of this BoardTimeframeComparisonInputV1.
        Current range start (ISO-8601)

        :return: The current_start of this BoardTimeframeComparisonInputV1.
        :rtype: str
        """
        return self._current_start

    @current_start.setter
    def current_start(self, current_start):
        """
        Sets the current_start of this BoardTimeframeComparisonInputV1.
        Current range start (ISO-8601)

        :param current_start: The current_start of this BoardTimeframeComparisonInputV1.
        :type: str
        """
        if current_start is None:
            raise ValueError("Invalid value for `current_start`, must not be `None`")

        self._current_start = current_start

    @property
    def limit(self):
        """
        Gets the limit of this BoardTimeframeComparisonInputV1.
        Maximum number of rows to fetch

        :return: The limit of this BoardTimeframeComparisonInputV1.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """
        Sets the limit of this BoardTimeframeComparisonInputV1.
        Maximum number of rows to fetch

        :param limit: The limit of this BoardTimeframeComparisonInputV1.
        :type: int
        """

        self._limit = limit

    @property
    def metric(self):
        """
        Gets the metric of this BoardTimeframeComparisonInputV1.
        Metric to compare: mean|sum|min|max

        :return: The metric of this BoardTimeframeComparisonInputV1.
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """
        Sets the metric of this BoardTimeframeComparisonInputV1.
        Metric to compare: mean|sum|min|max

        :param metric: The metric of this BoardTimeframeComparisonInputV1.
        :type: str
        """

        self._metric = metric

    @property
    def percent_threshold(self):
        """
        Gets the percent_threshold of this BoardTimeframeComparisonInputV1.
        Percent change threshold for reporting

        :return: The percent_threshold of this BoardTimeframeComparisonInputV1.
        :rtype: float
        """
        return self._percent_threshold

    @percent_threshold.setter
    def percent_threshold(self, percent_threshold):
        """
        Sets the percent_threshold of this BoardTimeframeComparisonInputV1.
        Percent change threshold for reporting

        :param percent_threshold: The percent_threshold of this BoardTimeframeComparisonInputV1.
        :type: float
        """

        self._percent_threshold = percent_threshold

    @property
    def tile_ids(self):
        """
        Gets the tile_ids of this BoardTimeframeComparisonInputV1.
        Optional list of tile IDs to compare

        :return: The tile_ids of this BoardTimeframeComparisonInputV1.
        :rtype: list[str]
        """
        return self._tile_ids

    @tile_ids.setter
    def tile_ids(self, tile_ids):
        """
        Sets the tile_ids of this BoardTimeframeComparisonInputV1.
        Optional list of tile IDs to compare

        :param tile_ids: The tile_ids of this BoardTimeframeComparisonInputV1.
        :type: list[str]
        """

        self._tile_ids = tile_ids

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, BoardTimeframeComparisonInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class RequestOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _activities: Optional[List[ActivityOutputV1]]
    _activity_graph: Optional[ActivityGraphOutputV1]
    _detailed_meters: Optional[List[DetailedMeterOutputV1]]
    _detailed_timers: Optional[List[DetailedTimerOutputV1]]
    _flame_graph: Optional[FoldedStackNodeV1]
    _href: str
    _parallelization_count: int
    _parameters: Optional[Dict[str, List[str]]]
    _progress: Optional[ProgressInformationOutputV1]
    _request_method: str
    _request_path: str
    _run_duration: int
    _user_email: str
    _username: str


    def __init__(
        self,
        activities: Optional[List[ActivityOutputV1]] = None,
        activity_graph: Optional[ActivityGraphOutputV1] = None,
        detailed_meters: Optional[List[DetailedMeterOutputV1]] = None,
        detailed_timers: Optional[List[DetailedTimerOutputV1]] = None,
        flame_graph: Optional[FoldedStackNodeV1] = None,
        href: Optional[str] = None,
        parallelization_count: Optional[int] = None,
        parameters: Optional[Dict[str, List[str]]] = None,
        progress: Optional[ProgressInformationOutputV1] = None,
        request_method: Optional[str] = None,
        request_path: Optional[str] = None,
        run_duration: Optional[int] = None,
        user_email: Optional[str] = None,
        username: Optional[str] = None,
    ) -> None: ...

    @property
    def activities(self) -> Optional[List[ActivityOutputV1]]: ...

    @activities.setter
    def activities(self, activities: Optional[List[ActivityOutputV1]]) -> None: ...

    @property
    def activity_graph(self) -> Optional[ActivityGraphOutputV1]: ...

    @activity_graph.setter
    def activity_graph(self, activity_graph: Optional[ActivityGraphOutputV1]) -> None: ...

    @property
    def detailed_meters(self) -> Optional[List[DetailedMeterOutputV1]]: ...

    @detailed_meters.setter
    def detailed_meters(self, detailed_meters: Optional[List[DetailedMeterOutputV1]]) -> None: ...

    @property
    def detailed_timers(self) -> Optional[List[DetailedTimerOutputV1]]: ...

    @detailed_timers.setter
    def detailed_timers(self, detailed_timers: Optional[List[DetailedTimerOutputV1]]) -> None: ...

    @property
    def flame_graph(self) -> Optional[FoldedStackNodeV1]: ...

    @flame_graph.setter
    def flame_graph(self, flame_graph: Optional[FoldedStackNodeV1]) -> None: ...

    @property
    def href(self) -> str: ...

    @href.setter
    def href(self, href: str) -> None: ...

    @property
    def parallelization_count(self) -> int: ...

    @parallelization_count.setter
    def parallelization_count(self, parallelization_count: int) -> None: ...

    @property
    def parameters(self) -> Optional[Dict[str, List[str]]]: ...

    @parameters.setter
    def parameters(self, parameters: Optional[Dict[str, List[str]]]) -> None: ...

    @property
    def progress(self) -> Optional[ProgressInformationOutputV1]: ...

    @progress.setter
    def progress(self, progress: Optional[ProgressInformationOutputV1]) -> None: ...

    @property
    def request_method(self) -> str: ...

    @request_method.setter
    def request_method(self, request_method: str) -> None: ...

    @property
    def request_path(self) -> str: ...

    @request_path.setter
    def request_path(self, request_path: str) -> None: ...

    @property
    def run_duration(self) -> int: ...

    @run_duration.setter
    def run_duration(self, run_duration: int) -> None: ...

    @property
    def user_email(self) -> str: ...

    @user_email.setter
    def user_email(self, user_email: str) -> None: ...

    @property
    def username(self) -> str: ...

    @username.setter
    def username(self, username: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ScheduledNotebookResultInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'error': 'str',
        'run_started_at': 'str',
        'run_time': 'int',
        'warning': 'str'
    }

    attribute_map = {
        'error': 'error',
        'run_started_at': 'runStartedAt',
        'run_time': 'runTime',
        'warning': 'warning'
    }

    def __init__(self, error=None, run_started_at=None, run_time=None, warning=None):
        """
        ScheduledNotebookResultInputV1 - a model defined in Swagger
        """

        self._error = None
        self._run_started_at = None
        self._run_time = None
        self._warning = None

        if error is not None:
          self.error = error
        if run_started_at is not None:
          self.run_started_at = run_started_at
        if run_time is not None:
          self.run_time = run_time
        if warning is not None:
          self.warning = warning

    @property
    def error(self):
        """
        Gets the error of this ScheduledNotebookResultInputV1.
        If not successful, the error message reporting the cause of the failure

        :return: The error of this ScheduledNotebookResultInputV1.
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """
        Sets the error of this ScheduledNotebookResultInputV1.
        If not successful, the error message reporting the cause of the failure

        :param error: The error of this ScheduledNotebookResultInputV1.
        :type: str
        """

        self._error = error

    @property
    def run_started_at(self):
        """
        Gets the run_started_at of this ScheduledNotebookResultInputV1.
        The ISO 8601 date of when this execution began (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :return: The run_started_at of this ScheduledNotebookResultInputV1.
        :rtype: str
        """
        return self._run_started_at

    @run_started_at.setter
    def run_started_at(self, run_started_at):
        """
        Sets the run_started_at of this ScheduledNotebookResultInputV1.
        The ISO 8601 date of when this execution began (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :param run_started_at: The run_started_at of this ScheduledNotebookResultInputV1.
        :type: str
        """
        if run_started_at is None:
            raise ValueError("Invalid value for `run_started_at`, must not be `None`")

        self._run_started_at = run_started_at

    @property
    def run_time(self):
        """
        Gets the run_time of this ScheduledNotebookResultInputV1.
        If successful, the time it took for the notebook to complete its execution (in milliseconds)

        :return: The run_time of this ScheduledNotebookResultInputV1.
        :rtype: int
        """
        return self._run_time

    @run_time.setter
    def run_time(self, run_time):
        """
        Sets the run_time of this ScheduledNotebookResultInputV1.
        If successful, the time it took for the notebook to complete its execution (in milliseconds)

        :param run_time: The run_time of this ScheduledNotebookResultInputV1.
        :type: int
        """

        self._run_time = run_time

    @property
    def warning(self):
        """
        Gets the warning of this ScheduledNotebookResultInputV1.
        If successful, any warning messages generated during the execution

        :return: The warning of this ScheduledNotebookResultInputV1.
        :rtype: str
        """
        return self._warning

    @warning.setter
    def warning(self, warning):
        """
        Sets the warning of this ScheduledNotebookResultInputV1.
        If successful, any warning messages generated during the execution

        :param warning: The warning of this ScheduledNotebookResultInputV1.
        :type: str
        """

        self._warning = warning

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ScheduledNotebookResultInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TableDefinitionOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'additional_properties': 'list[ScalarPropertyV1]',
        'batch_action': 'str',
        'column_definitions': 'list[ColumnDefinitionOutputV1]',
        'data_id': 'str',
        'datasource_class': 'str',
        'datasource_id': 'str',
        'description': 'str',
        'effective_permissions': 'PermissionsV1',
        'exports': 'list[ExportPreviewV1]',
        'id': 'str',
        'is_archived': 'bool',
        'is_redacted': 'bool',
        'name': 'str',
        'navigation_column_id': 'str',
        'scoped_to': 'str',
        'status_message': 'str',
        'subscription': 'ItemPreviewV1',
        'table_type': 'str',
        'translation_key': 'str',
        'type': 'str',
        'unique_id_column_name': 'str',
        'vantage': 'ItemPreviewV1'
    }

    attribute_map = {
        'additional_properties': 'additionalProperties',
        'batch_action': 'batchAction',
        'column_definitions': 'columnDefinitions',
        'data_id': 'dataId',
        'datasource_class': 'datasourceClass',
        'datasource_id': 'datasourceId',
        'description': 'description',
        'effective_permissions': 'effectivePermissions',
        'exports': 'exports',
        'id': 'id',
        'is_archived': 'isArchived',
        'is_redacted': 'isRedacted',
        'name': 'name',
        'navigation_column_id': 'navigationColumnId',
        'scoped_to': 'scopedTo',
        'status_message': 'statusMessage',
        'subscription': 'subscription',
        'table_type': 'tableType',
        'translation_key': 'translationKey',
        'type': 'type',
        'unique_id_column_name': 'uniqueIDColumnName',
        'vantage': 'vantage'
    }

    def __init__(self, additional_properties=None, batch_action=None, column_definitions=None, data_id=None, datasource_class=None, datasource_id=None, description=None, effective_permissions=None, exports=None, id=None, is_archived=False, is_redacted=False, name=None, navigation_column_id=None, scoped_to=None, status_message=None, subscription=None, table_type=None, translation_key=None, type=None, unique_id_column_name=None, vantage=None):
        """
        TableDefinitionOutputV1 - a model defined in Swagger
        """

        self._additional_properties = None
        self._batch_action = None
        self._column_definitions = None
        self._data_id = None
        self._datasource_class = None
        self._datasource_id = None
        self._description = None
        self._effective_permissions = None
        self._exports = None
        self._id = None
        self._is_archived = None
        self._is_redacted = None
        self._name = None
        self._navigation_column_id = None
        self._scoped_to = None
        self._status_message = None
        self._subscription = None
        self._table_type = None
        self._translation_key = None
        self._type = None
        self._unique_id_column_name = None
        self._vantage = None

        if additional_properties is not None:
          self.additional_properties = additional_properties
        if batch_action is not None:
          self.batch_action = batch_action
        if column_definitions is not None:
          self.column_definitions = column_definitions
        if data_id is not None:
          self.data_id = data_id
        if datasource_class is not None:
          self.datasource_class = datasource_class
        if datasource_id is not None:
          self.datasource_id = datasource_id
        if description is not None:
          self.description = description
        if effective_permissions is not None:
          self.effective_permissions = effective_permissions
        if exports is not None:
          self.exports = exports
        if id is not None:
          self.id = id
        if is_archived is not None:
          self.is_archived = is_archived
        if is_redacted is not None:
          self.is_redacted = is_redacted
        if name is not None:
          self.name = name
        if navigation_column_id is not None:
          self.navigation_column_id = navigation_column_id
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if status_message is not None:
          self.status_message = status_message
        if subscription is not None:
          self.subscription = subscription
        if table_type is not None:
          self.table_type = table_type
        if translation_key is not None:
          self.translation_key = translation_key
        if type is not None:
          self.type = type
        if unique_id_column_name is not None:
          self.unique_id_column_name = unique_id_column_name
        if vantage is not None:
          self.vantage = vantage

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this TableDefinitionOutputV1.
        Additional properties of the item

        :return: The additional_properties of this TableDefinitionOutputV1.
        :rtype: list[ScalarPropertyV1]
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this TableDefinitionOutputV1.
        Additional properties of the item

        :param additional_properties: The additional_properties of this TableDefinitionOutputV1.
        :type: list[ScalarPropertyV1]
        """

        self._additional_properties = additional_properties

    @property
    def batch_action(self):
        """
        Gets the batch_action of this TableDefinitionOutputV1.
        The behavior when the table receives batch updates

        :return: The batch_action of this TableDefinitionOutputV1.
        :rtype: str
        """
        return self._batch_action

    @batch_action.setter
    def batch_action(self, batch_action):
        """
        Sets the batch_action of this TableDefinitionOutputV1.
        The behavior when the table receives batch updates

        :param batch_action: The batch_action of this TableDefinitionOutputV1.
        :type: str
        """
        if batch_action is None:
            raise ValueError("Invalid value for `batch_action`, must not be `None`")

        self._batch_action = batch_action

    @property
    def column_definitions(self):
        """
        Gets the column_definitions of this TableDefinitionOutputV1.
        The Column Definitions for this Table Definition

        :return: The column_definitions of this TableDefinitionOutputV1.
        :rtype: list[ColumnDefinitionOutputV1]
        """
        return self._column_definitions

    @column_definitions.setter
    def column_definitions(self, column_definitions):
        """
        Sets the column_definitions of this TableDefinitionOutputV1.
        The Column Definitions for this Table Definition

        :param column_definitions: The column_definitions of this TableDefinitionOutputV1.
        :type: list[ColumnDefinitionOutputV1]
        """
        if column_definitions is None:
            raise ValueError("Invalid value for `column_definitions`, must not be `None`")

        self._column_definitions = column_definitions

    @property
    def data_id(self):
        """
        Gets the data_id of this TableDefinitionOutputV1.
        The data ID of this asset. Note: This is not the Seeq ID, but the unique identifier that the remote datasource uses.

        :return: The data_id of this TableDefinitionOutputV1.
        :rtype: str
        """
        return self._data_id

    @data_id.setter
    def data_id(self, data_id):
        """
        Sets the data_id of this TableDefinitionOutputV1.
        The data ID of this asset. Note: This is not the Seeq ID, but the unique identifier that the remote datasource uses.

        :param data_id: The data_id of this TableDefinitionOutputV1.
        :type: str
        """

        self._data_id = data_id

    @property
    def datasource_class(self):
        """
        Gets the datasource_class of this TableDefinitionOutputV1.
        The datasource class, which is the type of system holding the item, such as OSIsoft PI

        :return: The datasource_class of this TableDefinitionOutputV1.
        :rtype: str
        """
        return self._datasource_class

    @datasource_class.setter
    def datasource_class(self, datasource_class):
        """
        Sets the datasource_class of this TableDefinitionOutputV1.
        The datasource class, which is the type of system holding the item, such as OSIsoft PI

        :param datasource_class: The datasource_class of this TableDefinitionOutputV1.
        :type: str
        """

        self._datasource_class = datasource_class

    @property
    def datasource_id(self):
        """
        Gets the datasource_id of this TableDefinitionOutputV1.
        The datasource identifier, which is how the datasource holding this item identifies itself

        :return: The datasource_id of this TableDefinitionOutputV1.
        :rtype: str
        """
        return self._datasource_id

    @datasource_id.setter
    def datasource_id(self, datasource_id):
        """
        Sets the datasource_id of this TableDefinitionOutputV1.
        The datasource identifier, which is how the datasource holding this item identifies itself

        :param datasource_id: The datasource_id of this TableDefinitionOutputV1.
        :type: str
        """

        self._datasource_id = datasource_id

    @property
    def description(self):
        """
        Gets the description of this TableDefinitionOutputV1.
        Clarifying information or other plain language description of this item

        :return: The description of this TableDefinitionOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this TableDefinitionOutputV1.
        Clarifying information or other plain language description of this item

        :param description: The description of this TableDefinitionOutputV1.
        :type: str
        """

        self._description = description

    @property
    def effective_permissions(self):
        """
        Gets the effective_permissions of this TableDefinitionOutputV1.

        :return: The effective_permissions of this TableDefinitionOutputV1.
        :rtype: PermissionsV1
        """
        return self._effective_permissions

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions):
        """
        Sets the effective_permissions of this TableDefinitionOutputV1.

        :param effective_permissions: The effective_permissions of this TableDefinitionOutputV1.
        :type: PermissionsV1
        """

        self._effective_permissions = effective_permissions

    @property
    def exports(self):
        """
        Gets the exports of this TableDefinitionOutputV1.
        The exports configured for the table

        :return: The exports of this TableDefinitionOutputV1.
        :rtype: list[ExportPreviewV1]
        """
        return self._exports

    @exports.setter
    def exports(self, exports):
        """
        Sets the exports of this TableDefinitionOutputV1.
        The exports configured for the table

        :param exports: The exports of this TableDefinitionOutputV1.
        :type: list[ExportPreviewV1]
        """

        self._exports = exports

    @property
    def id(self):
        """
        Gets the id of this TableDefinitionOutputV1.
        The ID that can be used to interact with the item

        :return: The id of this TableDefinitionOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TableDefinitionOutputV1.
        The ID that can be used to interact with the item

        :param id: The id of this TableDefinitionOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def is_archived(self):
        """
        Gets the is_archived of this TableDefinitionOutputV1.
        Whether item is archived

        :return: The is_archived of this TableDefinitionOutputV1.
        :rtype: bool
        """
        return self._is_archived

    @is_archived.setter
    def is_archived(self, is_archived):
        """
        Sets the is_archived of this TableDefinitionOutputV1.
        Whether item is archived

        :param is_archived: The is_archived of this TableDefinitionOutputV1.
        :type: bool
        """

        self._is_archived = is_archived

    @property
    def is_redacted(self):
        """
        Gets the is_redacted of this TableDefinitionOutputV1.
        Whether item is redacted

        :return: The is_redacted of this TableDefinitionOutputV1.
        :rtype: bool
        """
        return self._is_redacted

    @is_redacted.setter
    def is_redacted(self, is_redacted):
        """
        Sets the is_redacted of this TableDefinitionOutputV1.
        Whether item is redacted

        :param is_redacted: The is_redacted of this TableDefinitionOutputV1.
        :type: bool
        """

        self._is_redacted = is_redacted

    @property
    def name(self):
        """
        Gets the name of this TableDefinitionOutputV1.
        The human readable name

        :return: The name of this TableDefinitionOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TableDefinitionOutputV1.
        The human readable name

        :param name: The name of this TableDefinitionOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def navigation_column_id(self):
        """
        Gets the navigation_column_id of this TableDefinitionOutputV1.
        The navigation column id used for overriding the default Data tab column representation. The navigation column can only be set on Scaling or Scaling CSV table types. Only Text and Item columns can be used as navigation columns.

        :return: The navigation_column_id of this TableDefinitionOutputV1.
        :rtype: str
        """
        return self._navigation_column_id

    @navigation_column_id.setter
    def navigation_column_id(self, navigation_column_id):
        """
        Sets the navigation_column_id of this TableDefinitionOutputV1.
        The navigation column id used for overriding the default Data tab column representation. The navigation column can only be set on Scaling or Scaling CSV table types. Only Text and Item columns can be used as navigation columns.

        :param navigation_column_id: The navigation_column_id of this TableDefinitionOutputV1.
        :type: str
        """

        self._navigation_column_id = navigation_column_id

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this TableDefinitionOutputV1.
        The ID of the workbook to which this item is scoped or null if it is in the global scope.

        :return: The scoped_to of this TableDefinitionOutputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this TableDefinitionOutputV1.
        The ID of the workbook to which this item is scoped or null if it is in the global scope.

        :param scoped_to: The scoped_to of this TableDefinitionOutputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def status_message(self):
        """
        Gets the status_message of this TableDefinitionOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :return: The status_message of this TableDefinitionOutputV1.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this TableDefinitionOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :param status_message: The status_message of this TableDefinitionOutputV1.
        :type: str
        """

        self._status_message = status_message

    @property
    def subscription(self):
        """
        Gets the subscription of this TableDefinitionOutputV1.

        :return: The subscription of this TableDefinitionOutputV1.
        :rtype: ItemPreviewV1
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """
        Sets the subscription of this TableDefinitionOutputV1.

        :param subscription: The subscription of this TableDefinitionOutputV1.
        :type: ItemPreviewV1
        """

        self._subscription = subscription

    @property
    def table_type(self):
        """
        Gets the table_type of this TableDefinitionOutputV1.
        The type of table

        :return: The table_type of this TableDefinitionOutputV1.
        :rtype: str
        """
        return self._table_type

    @table_type.setter
    def table_type(self, table_type):
        """
        Sets the table_type of this TableDefinitionOutputV1.
        The type of table

        :param table_type: The table_type of this TableDefinitionOutputV1.
        :type: str
        """
        if table_type is None:
            raise ValueError("Invalid value for `table_type`, must not be `None`")

        self._table_type = table_type

    @property
    def translation_key(self):
        """
        Gets the translation_key of this TableDefinitionOutputV1.
        The item's translation key, if any

        :return: The translation_key of this TableDefinitionOutputV1.
        :rtype: str
        """
        return self._translation_key

    @translation_key.setter
    def translation_key(self, translation_key):
        """
        Sets the translation_key of this TableDefinitionOutputV1.
        The item's translation key, if any

        :param translation_key: The translation_key of this TableDefinitionOutputV1.
        :type: str
        """

        self._translation_key = translation_key

    @property
    def type(self):
        """
        Gets the type of this TableDefinitionOutputV1.
        The type of the item

        :return: The type of this TableDefinitionOutputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this TableDefinitionOutputV1.
        The type of the item

        :param type: The type of this TableDefinitionOutputV1.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    @property
    def unique_id_column_name(self):
        """
        Gets the unique_id_column_name of this TableDefinitionOutputV1.
        The Unique ID column name for the Table, if applicable

        :return: The unique_id_column_name of this TableDefinitionOutputV1.
        :rtype: str
        """
        return self._unique_id_column_name

    @unique_id_column_name.setter
    def unique_id_column_name(self, unique_id_column_name):
        """
        Sets the unique_id_column_name of this TableDefinitionOutputV1.
        The Unique ID column name for the Table, if applicable

        :param unique_id_column_name: The unique_id_column_name of this TableDefinitionOutputV1.
        :type: str
        """

        self._unique_id_column_name = unique_id_column_name

    @property
    def vantage(self):
        """
        Gets the vantage of this TableDefinitionOutputV1.

        :return: The vantage of this TableDefinitionOutputV1.
        :rtype: ItemPreviewV1
        """
        return self._vantage

    @vantage.setter
    def vantage(self, vantage):
        """
        Sets the vantage of this TableDefinitionOutputV1.

        :param vantage: The vantage of this TableDefinitionOutputV1.
        :type: ItemPreviewV1
        """

        self._vantage = vantage

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TableDefinitionOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class CacheBlock(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _authoritative_region: Optional[AuthoritativeRegionOutputV1]
    _blob_id: Optional[int]
    _capsules: Optional[List[CapsuleV1]]
    _creation_time: Optional[str]
    _cursor: Optional[str]
    _last_access_time: Optional[str]
    _length_in_bytes: Optional[int]
    _length_in_datums: Optional[int]
    _record_id: Optional[int]
    _samples: Optional[List[SampleOutputV1]]
    _series_id: Optional[str]
    _ttl: Optional[int]


    def __init__(
        self,
        authoritative_region: Optional[AuthoritativeRegionOutputV1] = None,
        blob_id: Optional[int] = None,
        capsules: Optional[List[CapsuleV1]] = None,
        creation_time: Optional[str] = None,
        cursor: Optional[str] = None,
        last_access_time: Optional[str] = None,
        length_in_bytes: Optional[int] = None,
        length_in_datums: Optional[int] = None,
        record_id: Optional[int] = None,
        samples: Optional[List[SampleOutputV1]] = None,
        series_id: Optional[str] = None,
        ttl: Optional[int] = None,
    ) -> None: ...

    @property
    def authoritative_region(self) -> Optional[AuthoritativeRegionOutputV1]: ...

    @authoritative_region.setter
    def authoritative_region(self, authoritative_region: Optional[AuthoritativeRegionOutputV1]) -> None: ...

    @property
    def blob_id(self) -> Optional[int]: ...

    @blob_id.setter
    def blob_id(self, blob_id: Optional[int]) -> None: ...

    @property
    def capsules(self) -> Optional[List[CapsuleV1]]: ...

    @capsules.setter
    def capsules(self, capsules: Optional[List[CapsuleV1]]) -> None: ...

    @property
    def creation_time(self) -> Optional[str]: ...

    @creation_time.setter
    def creation_time(self, creation_time: Optional[str]) -> None: ...

    @property
    def cursor(self) -> Optional[str]: ...

    @cursor.setter
    def cursor(self, cursor: Optional[str]) -> None: ...

    @property
    def last_access_time(self) -> Optional[str]: ...

    @last_access_time.setter
    def last_access_time(self, last_access_time: Optional[str]) -> None: ...

    @property
    def length_in_bytes(self) -> Optional[int]: ...

    @length_in_bytes.setter
    def length_in_bytes(self, length_in_bytes: Optional[int]) -> None: ...

    @property
    def length_in_datums(self) -> Optional[int]: ...

    @length_in_datums.setter
    def length_in_datums(self, length_in_datums: Optional[int]) -> None: ...

    @property
    def record_id(self) -> Optional[int]: ...

    @record_id.setter
    def record_id(self, record_id: Optional[int]) -> None: ...

    @property
    def samples(self) -> Optional[List[SampleOutputV1]]: ...

    @samples.setter
    def samples(self, samples: Optional[List[SampleOutputV1]]) -> None: ...

    @property
    def series_id(self) -> Optional[str]: ...

    @series_id.setter
    def series_id(self, series_id: Optional[str]) -> None: ...

    @property
    def ttl(self) -> Optional[int]: ...

    @ttl.setter
    def ttl(self, ttl: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ContentWithMetadataListOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _asset_selections: Optional[List[AssetSelectionOutputV1]]
    _content_items: Optional[List[ContentWithMetadataOutputV1]]
    _date_ranges: Optional[List[DateRangeOutputV1]]


    def __init__(
        self,
        asset_selections: Optional[List[AssetSelectionOutputV1]] = None,
        content_items: Optional[List[ContentWithMetadataOutputV1]] = None,
        date_ranges: Optional[List[DateRangeOutputV1]] = None,
    ) -> None: ...

    @property
    def asset_selections(self) -> Optional[List[AssetSelectionOutputV1]]: ...

    @asset_selections.setter
    def asset_selections(self, asset_selections: Optional[List[AssetSelectionOutputV1]]) -> None: ...

    @property
    def content_items(self) -> Optional[List[ContentWithMetadataOutputV1]]: ...

    @content_items.setter
    def content_items(self, content_items: Optional[List[ContentWithMetadataOutputV1]]) -> None: ...

    @property
    def date_ranges(self) -> Optional[List[DateRangeOutputV1]]: ...

    @date_ranges.setter
    def date_ranges(self, date_ranges: Optional[List[DateRangeOutputV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class FolderSearchResultsV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'estimated_total_hits': 'int',
        'facet_distribution': 'dict(str, object)',
        'hits': 'list[dict(str, object)]',
        'hits_per_page': 'int',
        'page': 'int',
        'path': 'list[ItemPreviewV1]'
    }

    attribute_map = {
        'estimated_total_hits': 'estimatedTotalHits',
        'facet_distribution': 'facetDistribution',
        'hits': 'hits',
        'hits_per_page': 'hitsPerPage',
        'page': 'page',
        'path': 'path'
    }

    def __init__(self, estimated_total_hits=None, facet_distribution=None, hits=None, hits_per_page=None, page=None, path=None):
        """
        FolderSearchResultsV1 - a model defined in Swagger
        """

        self._estimated_total_hits = None
        self._facet_distribution = None
        self._hits = None
        self._hits_per_page = None
        self._page = None
        self._path = None

        if estimated_total_hits is not None:
          self.estimated_total_hits = estimated_total_hits
        if facet_distribution is not None:
          self.facet_distribution = facet_distribution
        if hits is not None:
          self.hits = hits
        if hits_per_page is not None:
          self.hits_per_page = hits_per_page
        if page is not None:
          self.page = page
        if path is not None:
          self.path = path

    @property
    def estimated_total_hits(self):
        """
        Gets the estimated_total_hits of this FolderSearchResultsV1.
        Total number of hits.

        :return: The estimated_total_hits of this FolderSearchResultsV1.
        :rtype: int
        """
        return self._estimated_total_hits

    @estimated_total_hits.setter
    def estimated_total_hits(self, estimated_total_hits):
        """
        Sets the estimated_total_hits of this FolderSearchResultsV1.
        Total number of hits.

        :param estimated_total_hits: The estimated_total_hits of this FolderSearchResultsV1.
        :type: int
        """
        if estimated_total_hits is None:
            raise ValueError("Invalid value for `estimated_total_hits`, must not be `None`")

        self._estimated_total_hits = estimated_total_hits

    @property
    def facet_distribution(self):
        """
        Gets the facet_distribution of this FolderSearchResultsV1.
        A dictionary of facet distributions, where top-level keys are properties and the sub-dictionaries map facet names to counts of matching content.

        :return: The facet_distribution of this FolderSearchResultsV1.
        :rtype: dict(str, object)
        """
        return self._facet_distribution

    @facet_distribution.setter
    def facet_distribution(self, facet_distribution):
        """
        Sets the facet_distribution of this FolderSearchResultsV1.
        A dictionary of facet distributions, where top-level keys are properties and the sub-dictionaries map facet names to counts of matching content.

        :param facet_distribution: The facet_distribution of this FolderSearchResultsV1.
        :type: dict(str, object)
        """
        if facet_distribution is None:
            raise ValueError("Invalid value for `facet_distribution`, must not be `None`")

        self._facet_distribution = facet_distribution

    @property
    def hits(self):
        """
        Gets the hits of this FolderSearchResultsV1.
        List of search result hits. Each list entry contains two keys: 'Content' and 'Formatted', which each contain the unmodified content but the latter contains values formatted for display based on the hitHighlightHtmlTag that was specified in the API call.

        :return: The hits of this FolderSearchResultsV1.
        :rtype: list[dict(str, object)]
        """
        return self._hits

    @hits.setter
    def hits(self, hits):
        """
        Sets the hits of this FolderSearchResultsV1.
        List of search result hits. Each list entry contains two keys: 'Content' and 'Formatted', which each contain the unmodified content but the latter contains values formatted for display based on the hitHighlightHtmlTag that was specified in the API call.

        :param hits: The hits of this FolderSearchResultsV1.
        :type: list[dict(str, object)]
        """
        if hits is None:
            raise ValueError("Invalid value for `hits`, must not be `None`")

        self._hits = hits

    @property
    def hits_per_page(self):
        """
        Gets the hits_per_page of this FolderSearchResultsV1.
        Number of hits that were requested to return per page.

        :return: The hits_per_page of this FolderSearchResultsV1.
        :rtype: int
        """
        return self._hits_per_page

    @hits_per_page.setter
    def hits_per_page(self, hits_per_page):
        """
        Sets the hits_per_page of this FolderSearchResultsV1.
        Number of hits that were requested to return per page.

        :param hits_per_page: The hits_per_page of this FolderSearchResultsV1.
        :type: int
        """
        if hits_per_page is None:
            raise ValueError("Invalid value for `hits_per_page`, must not be `None`")

        self._hits_per_page = hits_per_page

    @property
    def page(self):
        """
        Gets the page of this FolderSearchResultsV1.
        One-based page number that was retrieved. (i.e., 1 is always the first page.) If zero was specified for 'page' in the API call, then no hits are returned -- only the hit counts.

        :return: The page of this FolderSearchResultsV1.
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """
        Sets the page of this FolderSearchResultsV1.
        One-based page number that was retrieved. (i.e., 1 is always the first page.) If zero was specified for 'page' in the API call, then no hits are returned -- only the hit counts.

        :param page: The page of this FolderSearchResultsV1.
        :type: int
        """
        if page is None:
            raise ValueError("Invalid value for `page`, must not be `None`")

        self._page = page

    @property
    def path(self):
        """
        Gets the path of this FolderSearchResultsV1.
        The list of folders that specify where this these items are in the folder hierarchy.

        :return: The path of this FolderSearchResultsV1.
        :rtype: list[ItemPreviewV1]
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this FolderSearchResultsV1.
        The list of folders that specify where this these items are in the folder hierarchy.

        :param path: The path of this FolderSearchResultsV1.
        :type: list[ItemPreviewV1]
        """

        self._path = path

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, FolderSearchResultsV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class BoardTimeframeComparisonTileOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'skip_reason': 'str',
        'skipped': 'bool',
        'tile_id': 'str',
        'tile_name': 'str',
        'tile_type': 'str',
        'variations': 'list[BoardTimeframeComparisonMetricOutputV1]'
    }

    attribute_map = {
        'skip_reason': 'skipReason',
        'skipped': 'skipped',
        'tile_id': 'tileId',
        'tile_name': 'tileName',
        'tile_type': 'tileType',
        'variations': 'variations'
    }

    def __init__(self, skip_reason=None, skipped=None, tile_id=None, tile_name=None, tile_type=None, variations=None):
        """
        BoardTimeframeComparisonTileOutputV1 - a model defined in Swagger
        """

        self._skip_reason = None
        self._skipped = None
        self._tile_id = None
        self._tile_name = None
        self._tile_type = None
        self._variations = None

        if skip_reason is not None:
          self.skip_reason = skip_reason
        if skipped is not None:
          self.skipped = skipped
        if tile_id is not None:
          self.tile_id = tile_id
        if tile_name is not None:
          self.tile_name = tile_name
        if tile_type is not None:
          self.tile_type = tile_type
        if variations is not None:
          self.variations = variations

    @property
    def skip_reason(self):
        """
        Gets the skip_reason of this BoardTimeframeComparisonTileOutputV1.
        Reason the tile was skipped

        :return: The skip_reason of this BoardTimeframeComparisonTileOutputV1.
        :rtype: str
        """
        return self._skip_reason

    @skip_reason.setter
    def skip_reason(self, skip_reason):
        """
        Sets the skip_reason of this BoardTimeframeComparisonTileOutputV1.
        Reason the tile was skipped

        :param skip_reason: The skip_reason of this BoardTimeframeComparisonTileOutputV1.
        :type: str
        """

        self._skip_reason = skip_reason

    @property
    def skipped(self):
        """
        Gets the skipped of this BoardTimeframeComparisonTileOutputV1.
        Whether the tile was skipped

        :return: The skipped of this BoardTimeframeComparisonTileOutputV1.
        :rtype: bool
        """
        return self._skipped

    @skipped.setter
    def skipped(self, skipped):
        """
        Sets the skipped of this BoardTimeframeComparisonTileOutputV1.
        Whether the tile was skipped

        :param skipped: The skipped of this BoardTimeframeComparisonTileOutputV1.
        :type: bool
        """
        if skipped is None:
            raise ValueError("Invalid value for `skipped`, must not be `None`")

        self._skipped = skipped

    @property
    def tile_id(self):
        """
        Gets the tile_id of this BoardTimeframeComparisonTileOutputV1.
        Tile id

        :return: The tile_id of this BoardTimeframeComparisonTileOutputV1.
        :rtype: str
        """
        return self._tile_id

    @tile_id.setter
    def tile_id(self, tile_id):
        """
        Sets the tile_id of this BoardTimeframeComparisonTileOutputV1.
        Tile id

        :param tile_id: The tile_id of this BoardTimeframeComparisonTileOutputV1.
        :type: str
        """
        if tile_id is None:
            raise ValueError("Invalid value for `tile_id`, must not be `None`")

        self._tile_id = tile_id

    @property
    def tile_name(self):
        """
        Gets the tile_name of this BoardTimeframeComparisonTileOutputV1.
        Tile name

        :return: The tile_name of this BoardTimeframeComparisonTileOutputV1.
        :rtype: str
        """
        return self._tile_name

    @tile_name.setter
    def tile_name(self, tile_name):
        """
        Sets the tile_name of this BoardTimeframeComparisonTileOutputV1.
        Tile name

        :param tile_name: The tile_name of this BoardTimeframeComparisonTileOutputV1.
        :type: str
        """
        if tile_name is None:
            raise ValueError("Invalid value for `tile_name`, must not be `None`")

        self._tile_name = tile_name

    @property
    def tile_type(self):
        """
        Gets the tile_type of this BoardTimeframeComparisonTileOutputV1.
        Tile type

        :return: The tile_type of this BoardTimeframeComparisonTileOutputV1.
        :rtype: str
        """
        return self._tile_type

    @tile_type.setter
    def tile_type(self, tile_type):
        """
        Sets the tile_type of this BoardTimeframeComparisonTileOutputV1.
        Tile type

        :param tile_type: The tile_type of this BoardTimeframeComparisonTileOutputV1.
        :type: str
        """
        if tile_type is None:
            raise ValueError("Invalid value for `tile_type`, must not be `None`")

        self._tile_type = tile_type

    @property
    def variations(self):
        """
        Gets the variations of this BoardTimeframeComparisonTileOutputV1.
        Variations found for this tile

        :return: The variations of this BoardTimeframeComparisonTileOutputV1.
        :rtype: list[BoardTimeframeComparisonMetricOutputV1]
        """
        return self._variations

    @variations.setter
    def variations(self, variations):
        """
        Sets the variations of this BoardTimeframeComparisonTileOutputV1.
        Variations found for this tile

        :param variations: The variations of this BoardTimeframeComparisonTileOutputV1.
        :type: list[BoardTimeframeComparisonMetricOutputV1]
        """
        if variations is None:
            raise ValueError("Invalid value for `variations`, must not be `None`")

        self._variations = variations

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, BoardTimeframeComparisonTileOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TableComputeOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _compute_results: Dict[str, List[RowRulesResultV1]]
    _table_definition: TableDefinitionOutputV1


    def __init__(
        self,
        compute_results: Optional[Dict[str, List[RowRulesResultV1]]] = None,
        table_definition: Optional[TableDefinitionOutputV1] = None,
    ) -> None: ...

    @property
    def compute_results(self) -> Dict[str, List[RowRulesResultV1]]: ...

    @compute_results.setter
    def compute_results(self, compute_results: Dict[str, List[RowRulesResultV1]]) -> None: ...

    @property
    def table_definition(self) -> TableDefinitionOutputV1: ...

    @table_definition.setter
    def table_definition(self, table_definition: TableDefinitionOutputV1) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class DerivedFeatureV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _description: Optional[str]
    _id: Optional[str]
    _is_output: Optional[bool]
    _name: str
    _output_type: str
    _rules: List[FeatureRuleV1]


    def __init__(
        self,
        description: Optional[str] = None,
        id: Optional[str] = None,
        is_output: Optional[bool] = None,
        name: Optional[str] = None,
        output_type: Optional[str] = None,
        rules: Optional[List[FeatureRuleV1]] = None,
    ) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def id(self) -> Optional[str]: ...

    @id.setter
    def id(self, id: Optional[str]) -> None: ...

    @property
    def is_output(self) -> Optional[bool]: ...

    @is_output.setter
    def is_output(self, is_output: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def output_type(self) -> str: ...

    @output_type.setter
    def output_type(self, output_type: str) -> None: ...

    @property
    def rules(self) -> List[FeatureRuleV1]: ...

    @rules.setter
    def rules(self, rules: List[FeatureRuleV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class IssueSummaryOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'installed_on': 'str',
        'issue_type': 'str',
        'key': 'int',
        'summary': 'str',
        'version': 'str'
    }

    attribute_map = {
        'installed_on': 'installedOn',
        'issue_type': 'issueType',
        'key': 'key',
        'summary': 'summary',
        'version': 'version'
    }

    def __init__(self, installed_on=None, issue_type=None, key=None, summary=None, version=None):
        """
        IssueSummaryOutputV1 - a model defined in Swagger
        """

        self._installed_on = None
        self._issue_type = None
        self._key = None
        self._summary = None
        self._version = None

        if installed_on is not None:
          self.installed_on = installed_on
        if issue_type is not None:
          self.issue_type = issue_type
        if key is not None:
          self.key = key
        if summary is not None:
          self.summary = summary
        if version is not None:
          self.version = version

    @property
    def installed_on(self):
        """
        Gets the installed_on of this IssueSummaryOutputV1.
        The timestamp of when this issue was installed on the server

        :return: The installed_on of this IssueSummaryOutputV1.
        :rtype: str
        """
        return self._installed_on

    @installed_on.setter
    def installed_on(self, installed_on):
        """
        Sets the installed_on of this IssueSummaryOutputV1.
        The timestamp of when this issue was installed on the server

        :param installed_on: The installed_on of this IssueSummaryOutputV1.
        :type: str
        """
        if installed_on is None:
            raise ValueError("Invalid value for `installed_on`, must not be `None`")

        self._installed_on = installed_on

    @property
    def issue_type(self):
        """
        Gets the issue_type of this IssueSummaryOutputV1.
        The type of issue

        :return: The issue_type of this IssueSummaryOutputV1.
        :rtype: str
        """
        return self._issue_type

    @issue_type.setter
    def issue_type(self, issue_type):
        """
        Sets the issue_type of this IssueSummaryOutputV1.
        The type of issue

        :param issue_type: The issue_type of this IssueSummaryOutputV1.
        :type: str
        """
        if issue_type is None:
            raise ValueError("Invalid value for `issue_type`, must not be `None`")

        self._issue_type = issue_type

    @property
    def key(self):
        """
        Gets the key of this IssueSummaryOutputV1.
        The unique key that identifies the issue

        :return: The key of this IssueSummaryOutputV1.
        :rtype: int
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this IssueSummaryOutputV1.
        The unique key that identifies the issue

        :param key: The key of this IssueSummaryOutputV1.
        :type: int
        """
        if key is None:
            raise ValueError("Invalid value for `key`, must not be `None`")

        self._key = key

    @property
    def summary(self):
        """
        Gets the summary of this IssueSummaryOutputV1.
        A short description of what the issue

        :return: The summary of this IssueSummaryOutputV1.
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """
        Sets the summary of this IssueSummaryOutputV1.
        A short description of what the issue

        :param summary: The summary of this IssueSummaryOutputV1.
        :type: str
        """
        if summary is None:
            raise ValueError("Invalid value for `summary`, must not be `None`")

        self._summary = summary

    @property
    def version(self):
        """
        Gets the version of this IssueSummaryOutputV1.
        The version associated with this issue

        :return: The version of this IssueSummaryOutputV1.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this IssueSummaryOutputV1.
        The version associated with this issue

        :param version: The version of this IssueSummaryOutputV1.
        :type: str
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")

        self._version = version

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, IssueSummaryOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FormulaUpgradeOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _after_formula: Optional[str]
    _before_formula: Optional[str]
    _changes: Optional[List[FormulaUpgradeChangeV1]]
    _new_version: Optional[int]
    _old_version: Optional[int]


    def __init__(
        self,
        after_formula: Optional[str] = None,
        before_formula: Optional[str] = None,
        changes: Optional[List[FormulaUpgradeChangeV1]] = None,
        new_version: Optional[int] = None,
        old_version: Optional[int] = None,
    ) -> None: ...

    @property
    def after_formula(self) -> Optional[str]: ...

    @after_formula.setter
    def after_formula(self, after_formula: Optional[str]) -> None: ...

    @property
    def before_formula(self) -> Optional[str]: ...

    @before_formula.setter
    def before_formula(self, before_formula: Optional[str]) -> None: ...

    @property
    def changes(self) -> Optional[List[FormulaUpgradeChangeV1]]: ...

    @changes.setter
    def changes(self, changes: Optional[List[FormulaUpgradeChangeV1]]) -> None: ...

    @property
    def new_version(self) -> Optional[int]: ...

    @new_version.setter
    def new_version(self, new_version: Optional[int]) -> None: ...

    @property
    def old_version(self) -> Optional[int]: ...

    @old_version.setter
    def old_version(self, old_version: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class StoredTableSearchFailureOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'message_key': 'str',
        'row_id': 'str',
        'search_string': 'str',
        'stored_table_id': 'str'
    }

    attribute_map = {
        'message_key': 'messageKey',
        'row_id': 'rowId',
        'search_string': 'searchString',
        'stored_table_id': 'storedTableId'
    }

    def __init__(self, message_key=None, row_id=None, search_string=None, stored_table_id=None):
        """
        StoredTableSearchFailureOutputV1 - a model defined in Swagger
        """

        self._message_key = None
        self._row_id = None
        self._search_string = None
        self._stored_table_id = None

        if message_key is not None:
          self.message_key = message_key
        if row_id is not None:
          self.row_id = row_id
        if search_string is not None:
          self.search_string = search_string
        if stored_table_id is not None:
          self.stored_table_id = stored_table_id

    @property
    def message_key(self):
        """
        Gets the message_key of this StoredTableSearchFailureOutputV1.
        Message key for translating the failure message

        :return: The message_key of this StoredTableSearchFailureOutputV1.
        :rtype: str
        """
        return self._message_key

    @message_key.setter
    def message_key(self, message_key):
        """
        Sets the message_key of this StoredTableSearchFailureOutputV1.
        Message key for translating the failure message

        :param message_key: The message_key of this StoredTableSearchFailureOutputV1.
        :type: str
        """
        if message_key is None:
            raise ValueError("Invalid value for `message_key`, must not be `None`")

        self._message_key = message_key

    @property
    def row_id(self):
        """
        Gets the row_id of this StoredTableSearchFailureOutputV1.
        Id of the row in the stored table associated with this failure

        :return: The row_id of this StoredTableSearchFailureOutputV1.
        :rtype: str
        """
        return self._row_id

    @row_id.setter
    def row_id(self, row_id):
        """
        Sets the row_id of this StoredTableSearchFailureOutputV1.
        Id of the row in the stored table associated with this failure

        :param row_id: The row_id of this StoredTableSearchFailureOutputV1.
        :type: str
        """
        if row_id is None:
            raise ValueError("Invalid value for `row_id`, must not be `None`")

        self._row_id = row_id

    @property
    def search_string(self):
        """
        Gets the search_string of this StoredTableSearchFailureOutputV1.
        Search string that failed for the row in the stored table associated with this failure

        :return: The search_string of this StoredTableSearchFailureOutputV1.
        :rtype: str
        """
        return self._search_string

    @search_string.setter
    def search_string(self, search_string):
        """
        Sets the search_string of this StoredTableSearchFailureOutputV1.
        Search string that failed for the row in the stored table associated with this failure

        :param search_string: The search_string of this StoredTableSearchFailureOutputV1.
        :type: str
        """
        if search_string is None:
            raise ValueError("Invalid value for `search_string`, must not be `None`")

        self._search_string = search_string

    @property
    def stored_table_id(self):
        """
        Gets the stored_table_id of this StoredTableSearchFailureOutputV1.
        Id of the stored table associated with this failure

        :return: The stored_table_id of this StoredTableSearchFailureOutputV1.
        :rtype: str
        """
        return self._stored_table_id

    @stored_table_id.setter
    def stored_table_id(self, stored_table_id):
        """
        Sets the stored_table_id of this StoredTableSearchFailureOutputV1.
        Id of the stored table associated with this failure

        :param stored_table_id: The stored_table_id of this StoredTableSearchFailureOutputV1.
        :type: str
        """
        if stored_table_id is None:
            raise ValueError("Invalid value for `stored_table_id`, must not be `None`")

        self._stored_table_id = stored_table_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, StoredTableSearchFailureOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FormulaDocOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _children: Optional[List[SeeAlsoDocOutputV1]]
    _constants: Optional[List[str]]
    _description: Optional[str]
    _doc_created_at: Optional[str]
    _doc_updated_at: Optional[str]
    _documentation_href: Optional[str]
    _examples: Optional[List[FormulaExampleOutputV1]]
    _excel_synonyms: Optional[List[str]]
    _function_group_id: Optional[str]
    _functions: Optional[List[FunctionVariantOutputV1]]
    _images: Optional[List[str]]
    _keywords: Optional[List[str]]
    _package_created_at: Optional[str]
    _package_creator_contact_info: Optional[str]
    _package_creator_name: Optional[str]
    _package_id: Optional[str]
    _package_installer_name: Optional[str]
    _package_updated_at: Optional[str]
    _package_version: Optional[str]
    _parameters: Optional[List[ParameterDocOutputV1]]
    _parents: Optional[List[SeeAlsoDocOutputV1]]
    _see_alsos: Optional[List[SeeAlsoDocOutputV1]]
    _title: Optional[str]


    def __init__(
        self,
        children: Optional[List[SeeAlsoDocOutputV1]] = None,
        constants: Optional[List[str]] = None,
        description: Optional[str] = None,
        doc_created_at: Optional[str] = None,
        doc_updated_at: Optional[str] = None,
        documentation_href: Optional[str] = None,
        examples: Optional[List[FormulaExampleOutputV1]] = None,
        excel_synonyms: Optional[List[str]] = None,
        function_group_id: Optional[str] = None,
        functions: Optional[List[FunctionVariantOutputV1]] = None,
        images: Optional[List[str]] = None,
        keywords: Optional[List[str]] = None,
        package_created_at: Optional[str] = None,
        package_creator_contact_info: Optional[str] = None,
        package_creator_name: Optional[str] = None,
        package_id: Optional[str] = None,
        package_installer_name: Optional[str] = None,
        package_updated_at: Optional[str] = None,
        package_version: Optional[str] = None,
        parameters: Optional[List[ParameterDocOutputV1]] = None,
        parents: Optional[List[SeeAlsoDocOutputV1]] = None,
        see_alsos: Optional[List[SeeAlsoDocOutputV1]] = None,
        title: Optional[str] = None,
    ) -> None: ...

    @property
    def children(self) -> Optional[List[SeeAlsoDocOutputV1]]: ...

    @children.setter
    def children(self, children: Optional[List[SeeAlsoDocOutputV1]]) -> None: ...

    @property
    def constants(self) -> Optional[List[str]]: ...

    @constants.setter
    def constants(self, constants: Optional[List[str]]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def doc_created_at(self) -> Optional[str]: ...

    @doc_created_at.setter
    def doc_created_at(self, doc_created_at: Optional[str]) -> None: ...

    @property
    def doc_updated_at(self) -> Optional[str]: ...

    @doc_updated_at.setter
    def doc_updated_at(self, doc_updated_at: Optional[str]) -> None: ...

    @property
    def documentation_href(self) -> Optional[str]: ...

    @documentation_href.setter
    def documentation_href(self, documentation_href: Optional[str]) -> None: ...

    @property
    def examples(self) -> Optional[List[FormulaExampleOutputV1]]: ...

    @examples.setter
    def examples(self, examples: Optional[List[FormulaExampleOutputV1]]) -> None: ...

    @property
    def excel_synonyms(self) -> Optional[List[str]]: ...

    @excel_synonyms.setter
    def excel_synonyms(self, excel_synonyms: Optional[List[str]]) -> None: ...

    @property
    def function_group_id(self) -> Optional[str]: ...

    @function_group_id.setter
    def function_group_id(self, function_group_id: Optional[str]) -> None: ...

    @property
    def functions(self) -> Optional[List[FunctionVariantOutputV1]]: ...

    @functions.setter
    def functions(self, functions: Optional[List[FunctionVariantOutputV1]]) -> None: ...

    @property
    def images(self) -> Optional[List[str]]: ...

    @images.setter
    def images(self, images: Optional[List[str]]) -> None: ...

    @property
    def keywords(self) -> Optional[List[str]]: ...

    @keywords.setter
    def keywords(self, keywords: Optional[List[str]]) -> None: ...

    @property
    def package_created_at(self) -> Optional[str]: ...

    @package_created_at.setter
    def package_created_at(self, package_created_at: Optional[str]) -> None: ...

    @property
    def package_creator_contact_info(self) -> Optional[str]: ...

    @package_creator_contact_info.setter
    def package_creator_contact_info(self, package_creator_contact_info: Optional[str]) -> None: ...

    @property
    def package_creator_name(self) -> Optional[str]: ...

    @package_creator_name.setter
    def package_creator_name(self, package_creator_name: Optional[str]) -> None: ...

    @property
    def package_id(self) -> Optional[str]: ...

    @package_id.setter
    def package_id(self, package_id: Optional[str]) -> None: ...

    @property
    def package_installer_name(self) -> Optional[str]: ...

    @package_installer_name.setter
    def package_installer_name(self, package_installer_name: Optional[str]) -> None: ...

    @property
    def package_updated_at(self) -> Optional[str]: ...

    @package_updated_at.setter
    def package_updated_at(self, package_updated_at: Optional[str]) -> None: ...

    @property
    def package_version(self) -> Optional[str]: ...

    @package_version.setter
    def package_version(self, package_version: Optional[str]) -> None: ...

    @property
    def parameters(self) -> Optional[List[ParameterDocOutputV1]]: ...

    @parameters.setter
    def parameters(self, parameters: Optional[List[ParameterDocOutputV1]]) -> None: ...

    @property
    def parents(self) -> Optional[List[SeeAlsoDocOutputV1]]: ...

    @parents.setter
    def parents(self, parents: Optional[List[SeeAlsoDocOutputV1]]) -> None: ...

    @property
    def see_alsos(self) -> Optional[List[SeeAlsoDocOutputV1]]: ...

    @see_alsos.setter
    def see_alsos(self, see_alsos: Optional[List[SeeAlsoDocOutputV1]]) -> None: ...

    @property
    def title(self) -> Optional[str]: ...

    @title.setter
    def title(self, title: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class UsageOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _bytes: int
    _cache_type: Optional[str]
    _calls: int
    _content: int
    _context_writes: int
    _credits: float
    _identity: Optional[str]
    _identity_id: Optional[str]
    _impact_report_status: Optional[str]
    _impact_reports: int
    _prompts: int
    _source_label: Optional[str]
    _source_url: Optional[str]
    _timestamp: Optional[str]
    _tokens: int
    _type: Optional[str]
    _visits: int


    def __init__(
        self,
        bytes: Optional[int] = None,
        cache_type: Optional[str] = None,
        calls: Optional[int] = None,
        content: Optional[int] = None,
        context_writes: Optional[int] = None,
        credits: Optional[float] = None,
        identity: Optional[str] = None,
        identity_id: Optional[str] = None,
        impact_report_status: Optional[str] = None,
        impact_reports: Optional[int] = None,
        prompts: Optional[int] = None,
        source_label: Optional[str] = None,
        source_url: Optional[str] = None,
        timestamp: Optional[str] = None,
        tokens: Optional[int] = None,
        type: Optional[str] = None,
        visits: Optional[int] = None,
    ) -> None: ...

    @property
    def bytes(self) -> int: ...

    @bytes.setter
    def bytes(self, bytes: int) -> None: ...

    @property
    def cache_type(self) -> Optional[str]: ...

    @cache_type.setter
    def cache_type(self, cache_type: Optional[str]) -> None: ...

    @property
    def calls(self) -> int: ...

    @calls.setter
    def calls(self, calls: int) -> None: ...

    @property
    def content(self) -> int: ...

    @content.setter
    def content(self, content: int) -> None: ...

    @property
    def context_writes(self) -> int: ...

    @context_writes.setter
    def context_writes(self, context_writes: int) -> None: ...

    @property
    def credits(self) -> float: ...

    @credits.setter
    def credits(self, credits: float) -> None: ...

    @property
    def identity(self) -> Optional[str]: ...

    @identity.setter
    def identity(self, identity: Optional[str]) -> None: ...

    @property
    def identity_id(self) -> Optional[str]: ...

    @identity_id.setter
    def identity_id(self, identity_id: Optional[str]) -> None: ...

    @property
    def impact_report_status(self) -> Optional[str]: ...

    @impact_report_status.setter
    def impact_report_status(self, impact_report_status: Optional[str]) -> None: ...

    @property
    def impact_reports(self) -> int: ...

    @impact_reports.setter
    def impact_reports(self, impact_reports: int) -> None: ...

    @property
    def prompts(self) -> int: ...

    @prompts.setter
    def prompts(self, prompts: int) -> None: ...

    @property
    def source_label(self) -> Optional[str]: ...

    @source_label.setter
    def source_label(self, source_label: Optional[str]) -> None: ...

    @property
    def source_url(self) -> Optional[str]: ...

    @source_url.setter
    def source_url(self, source_url: Optional[str]) -> None: ...

    @property
    def timestamp(self) -> Optional[str]: ...

    @timestamp.setter
    def timestamp(self, timestamp: Optional[str]) -> None: ...

    @property
    def tokens(self) -> int: ...

    @tokens.setter
    def tokens(self, tokens: int) -> None: ...

    @property
    def type(self) -> Optional[str]: ...

    @type.setter
    def type(self, type: Optional[str]) -> None: ...

    @property
    def visits(self) -> int: ...

    @visits.setter
    def visits(self, visits: int) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class BoardTimeframeComparisonResultOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _baseline_range: str
    _board_id: str
    _board_name: str
    _current_range: str
    _tiles: List[BoardTimeframeComparisonTileOutputV1]
    _tiles_analyzed: int
    _tiles_skipped: int


    def __init__(
        self,
        baseline_range: Optional[str] = None,
        board_id: Optional[str] = None,
        board_name: Optional[str] = None,
        current_range: Optional[str] = None,
        tiles: Optional[List[BoardTimeframeComparisonTileOutputV1]] = None,
        tiles_analyzed: Optional[int] = None,
        tiles_skipped: Optional[int] = None,
    ) -> None: ...

    @property
    def baseline_range(self) -> str: ...

    @baseline_range.setter
    def baseline_range(self, baseline_range: str) -> None: ...

    @property
    def board_id(self) -> str: ...

    @board_id.setter
    def board_id(self, board_id: str) -> None: ...

    @property
    def board_name(self) -> str: ...

    @board_name.setter
    def board_name(self, board_name: str) -> None: ...

    @property
    def current_range(self) -> str: ...

    @current_range.setter
    def current_range(self, current_range: str) -> None: ...

    @property
    def tiles(self) -> List[BoardTimeframeComparisonTileOutputV1]: ...

    @tiles.setter
    def tiles(self, tiles: List[BoardTimeframeComparisonTileOutputV1]) -> None: ...

    @property
    def tiles_analyzed(self) -> int: ...

    @tiles_analyzed.setter
    def tiles_analyzed(self, tiles_analyzed: int) -> None: ...

    @property
    def tiles_skipped(self) -> int: ...

    @tiles_skipped.setter
    def tiles_skipped(self, tiles_skipped: int) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class JobOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _configuration: Optional[Dict[str, Any]]
    _currently_running: bool
    _document_id: Optional[str]
    _document_name: Optional[str]
    _duration: Optional[int]
    _group: str
    _id: str
    _next_run_time: Optional[str]
    _previous_run_time: Optional[str]
    _result: Optional[str]
    _status: Optional[str]
    _status_message: Optional[str]
    _topic_id: Optional[str]
    _topic_name: Optional[str]
    _user_id: Optional[str]


    def __init__(
        self,
        configuration: Optional[Dict[str, Any]] = None,
        currently_running: Optional[bool] = None,
        document_id: Optional[str] = None,
        document_name: Optional[str] = None,
        duration: Optional[int] = None,
        group: Optional[str] = None,
        id: Optional[str] = None,
        next_run_time: Optional[str] = None,
        previous_run_time: Optional[str] = None,
        result: Optional[str] = None,
        status: Optional[str] = None,
        status_message: Optional[str] = None,
        topic_id: Optional[str] = None,
        topic_name: Optional[str] = None,
        user_id: Optional[str] = None,
    ) -> None: ...

    @property
    def configuration(self) -> Optional[Dict[str, Any]]: ...

    @configuration.setter
    def configuration(self, configuration: Optional[Dict[str, Any]]) -> None: ...

    @property
    def currently_running(self) -> bool: ...

    @currently_running.setter
    def currently_running(self, currently_running: bool) -> None: ...

    @property
    def document_id(self) -> Optional[str]: ...

    @document_id.setter
    def document_id(self, document_id: Optional[str]) -> None: ...

    @property
    def document_name(self) -> Optional[str]: ...

    @document_name.setter
    def document_name(self, document_name: Optional[str]) -> None: ...

    @property
    def duration(self) -> Optional[int]: ...

    @duration.setter
    def duration(self, duration: Optional[int]) -> None: ...

    @property
    def group(self) -> str: ...

    @group.setter
    def group(self, group: str) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def next_run_time(self) -> Optional[str]: ...

    @next_run_time.setter
    def next_run_time(self, next_run_time: Optional[str]) -> None: ...

    @property
    def previous_run_time(self) -> Optional[str]: ...

    @previous_run_time.setter
    def previous_run_time(self, previous_run_time: Optional[str]) -> None: ...

    @property
    def result(self) -> Optional[str]: ...

    @result.setter
    def result(self, result: Optional[str]) -> None: ...

    @property
    def status(self) -> Optional[str]: ...

    @status.setter
    def status(self, status: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def topic_id(self) -> Optional[str]: ...

    @topic_id.setter
    def topic_id(self, topic_id: Optional[str]) -> None: ...

    @property
    def topic_name(self) -> Optional[str]: ...

    @topic_name.setter
    def topic_name(self, topic_name: Optional[str]) -> None: ...

    @property
    def user_id(self) -> Optional[str]: ...

    @user_id.setter
    def user_id(self, user_id: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class DirectItemIdsSourceV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _asset_id: Optional[str]
    _condition_stats: Optional[List[ConditionTableStatInputForDirectItemsV1]]
    _item_ids: List[str]


    def __init__(
        self,
        asset_id: Optional[str] = None,
        condition_stats: Optional[List[ConditionTableStatInputForDirectItemsV1]] = None,
        item_ids: Optional[List[str]] = None,
    ) -> None: ...

    @property
    def asset_id(self) -> Optional[str]: ...

    @asset_id.setter
    def asset_id(self, asset_id: Optional[str]) -> None: ...

    @property
    def condition_stats(self) -> Optional[List[ConditionTableStatInputForDirectItemsV1]]: ...

    @condition_stats.setter
    def condition_stats(self, condition_stats: Optional[List[ConditionTableStatInputForDirectItemsV1]]) -> None: ...

    @property
    def item_ids(self) -> List[str]: ...

    @item_ids.setter
    def item_ids(self, item_ids: List[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class FormulasApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def clear_cache(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def clear_cache_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def compile_formula(
        self,
        **kwargs: Any,
    ) -> FormulaCompileOutputV1: ...

    def compile_formula_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def compile_formula_and_parameters(
        self,
        **kwargs: Any,
    ) -> FormulaCompileOutputV1: ...

    def compile_formula_and_parameters_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_function(
        self,
        **kwargs: Any,
    ) -> CalculatedItemOutputV1: ...

    def create_function_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_item(
        self,
        **kwargs: Any,
    ) -> FormulaItemOutputV1: ...

    def create_item_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_formula_doc(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_formula_doc_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_function(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_function_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_package(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_package_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def experimental(
        self,
        **kwargs: Any,
    ) -> FormulaGenericOutputV1: ...

    def experimental_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def formula_explainer(
        self,
        **kwargs: Any,
    ) -> FormulaGenericOutputV1: ...

    def formula_explainer_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def formula_explainer_markdown(
        self,
        **kwargs: Any,
    ) -> None: ...

    def formula_explainer_markdown_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_constant_name_list(
        self,
        **kwargs: Any,
    ) -> List[str]: ...

    def get_constant_name_list_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_formula_doc(
        self,
        **kwargs: Any,
    ) -> FormulaDocOutputV1: ...

    def get_formula_doc_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_formula_docs(
        self,
        **kwargs: Any,
    ) -> FormulaDocSummariesOutputV1: ...

    def get_formula_docs_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_formula_functions(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_formula_functions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_function(
        self,
        **kwargs: Any,
    ) -> CalculatedItemOutputV1: ...

    def get_function_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_item(
        self,
        **kwargs: Any,
    ) -> FormulaItemOutputV1: ...

    def get_item_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_package(
        self,
        **kwargs: Any,
    ) -> FormulaPackageOutputV1: ...

    def get_package_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_packages(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_packages_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def import_package(
        self,
        **kwargs: Any,
    ) -> FormulaPackageImportOutputV1: ...

    def import_package_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_formula_doc(
        self,
        **kwargs: Any,
    ) -> FormulaDocOutputV1: ...

    def put_formula_doc_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_package(
        self,
        **kwargs: Any,
    ) -> FormulaPackageOutputV1: ...

    def put_package_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def run_formula(
        self,
        **kwargs: Any,
    ) -> FormulaRunOutputV1: ...

    def run_formula_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def run_formula_0(
        self,
        **kwargs: Any,
    ) -> FormulaRunOutputV1: ...

    def run_formula_0_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_function(
        self,
        **kwargs: Any,
    ) -> CalculatedItemOutputV1: ...

    def update_function_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
